%define oname           OpenFOAM
%define openfoam_name   %{oname}-%{version}
%define foam_inst_dir   %{_libdir}/%{oname}
%define openfoam_dir    %{foam_inst_dir}/%{openfoam_name}
%define thirdparty_name ThirdParty-%{version}
%define thirdparty_dir  %{foam_inst_dir}/%{thirdparty_name}

Name:          openfoam
Version:       2.2.2
Release:       %mkrel 0
Summary:       Open Source Field Operation and Manipulation
License:       GPL-3.0
Group:         Sciences/Physics
Url:           http://www.openfoam.org
Source0:       http://downloads.sourceforge.net/foam/%{openfoam_name}.tgz
Source1:       http://downloads.sourceforge.net/foam/%{thirdparty_name}.tgz
BuildRequires: bison
BuildRequires: cmake
BuildRequires: fdupes
BuildRequires: flex
BuildRequires: gcc-c++
BuildRequires: openmpi-devel
BuildRequires: ptscotch-openmpi-devel
BuildRequires: zlib-devel
Requires:      gcc-c++

%description
Open Source Field Operation and Manipulation is a CFD software and library.

%package       doc
Summary:       Development files for %{name}
Group:         Sciences/Physics
Requires:      %{name} = %{version}

%description   doc
The %{name}-doc package contains the documentation files
of %{name}.

%package       tutorials
Summary:       Development files for %{name}
Group:         Sciences/Physics
Requires:      %{name} = %{version}

%description   tutorials
The %{name}-tutorials package contains tutorials and examples
for %{name}.


%prep
%setup -T -c -n %{oname}
tar xzf %{S:0}
tar xzf %{S:1}

sed -i 's|foamInstall=$HOME/$WM_PROJECT|foamInstall=$RPM_BUILD_DIR/$WM_PROJECT|' %{oname}-%{version}/etc/bashrc
sed -i 's/WM_MPLIB=OPENMPI/WM_MPLIB=SYSTEMOPENMPI/' %{oname}-%{version}/etc/bashrc

%build
cd %{oname}-%{version}
source etc/bashrc
export WM_NCOMPPROCS=$(echo %{?_smp_mflags} | sed 's/-j//')
wmake all

%install
# Match binaries distributed by upstream (reducing from 800+ to 300+ Mb install)
find %{openfoam_name}/applications \( -name \*.o -o -name \*.dep \) | xargs rm -f
find %{openfoam_name}/src \( -name \*.o -o -name \*.dep \) | xargs rm -f
%ifarch x86_64
LIBDIR=linux64GccDPOpt
%else
LIBDIR=linuxGccDPOpt
%endif
for make in `find %{openfoam_name} -name Make`; do
    rm -fr $make/$LIBDIR
done
mkdir -p %{buildroot}%{foam_inst_dir}
cp -fpar %{openfoam_name} %{buildroot}%{foam_inst_dir}

for filela in `find %{thirdparty_name}/platforms -name \*.la`; do
  perl -pi -e "s|(libdir=').*(/ThirdParty.*)|$1%{foam_inst_dir}$2|;" $filela
done

mkdir -p %{buildroot}%{thirdparty_dir}
cp -fpar %{thirdparty_name}/platforms %{buildroot}%{thirdparty_dir}

# Set the base directory in rc files
sed -i 's|foamInstall=$RPM_BUILD_DIR/$WM_PROJECT|foamInstall=%{foam_inst_dir}/$WM_PROJECT|' \
   %{buildroot}%{openfoam_dir}/etc/bashrc
sed -i 's|foamInstall=$HOME/$WM_PROJECT|foamInstall=%{foam_inst_dir}/$WM_PROJECT|' \
   %{buildroot}%{openfoam_dir}/etc/cshrc

# avoid dependency on /usr/xpg4/bin/sh
rm -f %{buildroot}%{openfoam_dir}/bin/tools/replaceAllShellSun

# Remove unwanted files
rm -f %{buildroot}%{openfoam_dir}/{.build,.gitignore,.timeStamp}

# correct permissions
find %{buildroot}%{openfoam_dir} -perm 0640 | xargs chmod 0644
find %{buildroot}%{openfoam_dir} -perm 0750 | xargs chmod 0755

# replace duplicates by symlinks
%fdupes %{buildroot}%{openfoam_dir}/tutorials
%fdupes %{buildroot}%{openfoam_dir}/applications
%fdupes %{buildroot}%{openfoam_dir}/wmake

%fdupes %{buildroot}%{openfoam_dir}

%files
%defattr(-,root,root)
%dir %{foam_inst_dir}
%dir %{openfoam_dir}
%dir %{openfoam_dir}/etc
%{thirdparty_dir}
%{openfoam_dir}/bin
%{openfoam_dir}/etc/config
%{openfoam_dir}/etc/thermoData
%{openfoam_dir}/etc/*rc
%{openfoam_dir}/etc/caseDicts
%{openfoam_dir}/etc/cellModels
%{openfoam_dir}/etc/controlDict
%{openfoam_dir}/platforms
%{openfoam_dir}/COPYING
%{openfoam_dir}/README.*
%{openfoam_dir}/Allwmake
%{openfoam_dir}/applications
%{openfoam_dir}/etc/codeTemplates
%{openfoam_dir}/src
%{openfoam_dir}/wmake

%files doc
%defattr(-,root,root)
%{openfoam_dir}/doc

%files tutorials
%defattr(-,root,root)
%{openfoam_dir}/tutorials



%changelog
* Mon Dec 02 2013 philippem <philippem> 2.2.2-0.mga4
+ Revision: 554606
- imported package openfoam

